=========
storjcore
=========

|BuildLink|_ |CoverageLink|_ |LicenseLink|_ |IssuesLink|_


.. |BuildLink| image:: https://travis-ci.org/Storj/storjcore.svg?branch=master
.. _BuildLink: https://travis-ci.org/Storj/storjcore

.. |CoverageLink| image:: https://coveralls.io/repos/Storj/storjcore/badge.svg
.. _CoverageLink: https://coveralls.io/r/Storj/storjcore

.. |LicenseLink| image:: https://img.shields.io/badge/license-MIT-blue.svg
.. _LicenseLink: https://raw.githubusercontent.com/Storj/storjcore

.. |IssuesLink| image:: https://img.shields.io/github/issues/Storj/storjcore.svg
.. _IssuesLink: https://github.com/Storj/storjcore/issues

Storj core library.

